@@ -239,6 +239,7 @@ namespace FrameAPI
 	   m_output_start( 0 ),
 	   m_output_stop( 0 ),
 	   m_output_type( "" ),
+	   padding( 0 ),
 	   m_rds_level( 0 ),
 	   m_seconds_per_frame( 0 )
       {
@@ -275,6 +276,7 @@ namespace FrameAPI
 	   m_output_start( Start ),
 	   m_output_stop( Stop ),
 	   m_output_type( type ),
+	   padding( 0 ),
 	   m_rds_level( 0 ),
 	   m_seconds_per_frame( SecondsPerFrame )
       {
@@ -313,6 +315,7 @@ namespace FrameAPI
 	   m_output_start( Source.m_output_start ),
 	   m_output_stop( Source.m_output_stop ),
 	   m_output_type( Source.m_output_type ),
+	   padding( Source.Padding( ) ),
 	   m_rds_level( Source.m_rds_level ),
 	   m_seconds_per_frame( Source.m_seconds_per_frame )
       {
@@ -825,21 +828,21 @@ void RDSFrame::
 ProcessRequest( stream_type Output )
 {
    static const char* caller = "RDSFrame::ProcessRequest";
+
    if ( ! Output )
    {
       throw std::runtime_error( "Invalid Output stream" );
    }
    m_stream = Output;
    m_stream->IFOList( m_ifo_list );
-#if 0 || 1
+
    const LDASTools::AL::GPSTime	user_start( m_options.OutputTimeStart( ), 0 );
    const LDASTools::AL::GPSTime	user_stop( m_options.OutputTimeEnd( ), 0 );
-#endif /* 0 */
 
-   LDASTools::AL::GPSTime	frame_start;
+   LDASTools::AL::GPSTime	data_start;
    LDASTools::AL::GPSTime	data_stop;
-   REAL_8		data_dt;
-   INT_4U 		frames_to_write( 0 );
+   REAL_8		        data_dt;
+   INT_4U 			frames_to_write( 0 );
       
 
    ChannelCacheEntry::fr_adc_data_type	adc;
@@ -860,25 +863,25 @@ ProcessRequest( stream_type Output )
       //-----------------------------------------------------------------
       // Initialize
       //-----------------------------------------------------------------
-      m_stream->UserRange( m_options.OutputTimeStart( ),
-			   m_options.OutputTimeEnd( ) );
-      frame_start = m_p->GetStart( );
+      data_start = m_p->GetStart( );
       data_stop = m_p->GetStop( );
       
-      QUEUE_LOG_MESSAGE( "frame_start: " << frame_start
+      rangeOptimizer( user_start, user_stop,
+		      data_start, data_stop );
+
+      m_stream->UserRange( user_start.GetSeconds( ),
+			   user_stop.GetSeconds( ) );
+
+      QUEUE_LOG_MESSAGE( "data_start: " << data_start
 			 << " data_stop: " << data_stop,
 			 MT_DEBUG, 30,
 			 caller,
 			 "RDSFrame" );
-#if 0
-      INT_4U	frame_file_start( frame_start.GetSeconds( ) );
-      INT_4U	frame_file_deltaT( 0 );
-#endif /* 0 */
 
-      if ( frame_start != GPSTime( m_options.OutputTimeStart( ), 0 ) )
+      if ( data_start != GPSTime( m_options.OutputTimeStart( ), 0 ) )
       {
 	 data_dt = GPSTime( m_options.OutputTimeStart( ), 0 ) -
-	    frame_start;
+	    data_start;
       }
       else
       {
@@ -891,48 +894,51 @@ ProcessRequest( stream_type Output )
       const GPSTime stop( ( stopRequest( ) == STOP_DATA )
 			 ? data_stop
 			 : user_stop );
-      while( frame_start < stop )
+      while( data_start < stop )
       {
-	 QUEUE_LOG_MESSAGE( "frame_start: " << frame_start
+	 QUEUE_LOG_MESSAGE( "data_start: " << data_start
+			    << " user_start: " << user_start
 			    << " user_stop: " << user_stop
 			    << " data_stop: " << data_stop
 			    << " stop: " << stop
+			    << " data_dt: " << data_dt
+			    << " frames_to_write: " << frames_to_write
 			    ,
 			    MT_DEBUG, 30,
 			    caller,
 			    "RDSFrame" );
-	 if ( frame_start == GPSTime( m_options.OutputTimeStart( ), 0 ) )
+	 if ( data_start == GPSTime( m_options.OutputTimeStart( ), 0 ) )
 	 {
 	    // This is the case where the dt needs to be reset.
 	    data_dt = m_options.SecondsPerFrame( );
 	 }
-	 if ( frame_start < user_stop )
+	 if ( data_start < user_stop )
 	 {
 	    //----------------------------------------------------------
 	    // Check to see if the data_dt needs to be adjusted
 	    //----------------------------------------------------------
-	    if ( ( frame_start + data_dt ) > user_stop )
+	    if ( ( data_start + data_dt ) > user_stop )
 	    {
-	       data_dt = user_stop - frame_start;
+	       data_dt = user_stop - data_start;
 	    }
 	 } else {
 	    //-----------------------------------------------------------
 	    // For the case where the data stops beyond the user's
 	    //   request, squeeze everything into a final frame.
 	    //-----------------------------------------------------------
-	    data_dt = ( data_stop - frame_start );
+	    data_dt = ( data_stop - data_start );
 	 }
 	 if ( frames_to_write == 0 )
 	 {
 	    frames_to_write = m_options.FramesPerFile( );
-	    QUEUE_LOG_MESSAGE( "frame_start: " << frame_start
+	    QUEUE_LOG_MESSAGE( "data_start: " << data_start
 			       << " data_dt: " << data_dt
 			       << " frames_to_write: " << frames_to_write
 			       ,
 			       MT_DEBUG, 30,
 			       caller,
 			       "RDSFrame" );
-	    m_stream->Next( frame_start, data_dt, frames_to_write );
+	    m_stream->Next( data_start, data_dt, frames_to_write );
 	    QUEUE_LOG_MESSAGE( "frames_to_write: " << frames_to_write
 			       ,
 			       MT_DEBUG, 30,
@@ -952,7 +958,7 @@ ProcessRequest( stream_type Output )
 	 // Add in channel information
 	 //--------------------------------------------------------------
 	 m_p->RetrieveChannels( mResultFrame, *this,
-				frame_start, data_dt,
+				data_start, data_dt,
 				m_options );
 	 QUEUE_LOG_MESSAGE( "Frame: " << mResultFrame->GetName( )
 			    << " FrAdcData Entries: "  << ( ( mResultFrame->GetRawData( ) )
@@ -961,7 +967,7 @@ ProcessRequest( stream_type Output )
 			    << " FrProcData: " << mResultFrame->RefProcData( ).size( )
 			    ,
 			    MT_DEBUG, 30,
-			    "RDSFrame::ProcessRequest",
+			    caller,
 			    "CreateRDS" );
 	 //--------------------------------------------------------------
 	 // Post process the concatinated data
@@ -985,6 +991,11 @@ ProcessRequest( stream_type Output )
 	       //--------------------------------------------------------
 	       // Processing FrAdcData
 	       //--------------------------------------------------------
+	       QUEUE_LOG_MESSAGE( "Processing FrAdcData"
+			    ,
+			    MT_DEBUG, 40,
+			    caller,
+			    "CreateRDS" );
 	       processChannel( (*current).FrAdcData( ) );
 	    }
 	    else if ( (*current).FrProcData( ) )
@@ -992,6 +1003,11 @@ ProcessRequest( stream_type Output )
 	       //--------------------------------------------------------
 	       // Processing FrProcData
 	       //--------------------------------------------------------
+	       QUEUE_LOG_MESSAGE( "Processing FrProcData"
+			    ,
+			    MT_DEBUG, 40,
+			    caller,
+			    "CreateRDS" );
 	       processChannel( (*current).FrProcData( ) );
 	    }
 	    else
@@ -1008,17 +1024,17 @@ ProcessRequest( stream_type Output )
 			    << " FrProcData: " << mResultFrame->RefProcData( ).size( )
 			    ,
 			    MT_DEBUG, 30,
-			    "RDSFrame::ProcessRequest",
+			    caller,
 			    "CreateRDS" );
 	 if ( mResultFrame.get( ) )
 	 {
 	    //----------------------------------------------------------
 	    // Correct some information
 	    //----------------------------------------------------------
-	    mResultFrame->SetGTime( frame_start );
+	    mResultFrame->SetGTime( data_start );
 	    mResultFrame->SetDt( data_dt );
 	    QUEUE_LOG_MESSAGE( "Setting result frame attributes:"
-			       << " frame_start: " << frame_start
+			       << " data_start: " << data_start
 			       << " data_dt: " << data_dt
 			       ,
 			       MT_DEBUG, 30,
@@ -1051,53 +1067,49 @@ ProcessRequest( stream_type Output )
 	    //----------------------------------------------------------
 	    writeFrameToStream( );
 	 } // if ( mResultFrame.get( ) )
-#if 0
-	 //--------------------------------------------------------------
-	 // Advance the frame file duration
-	 //--------------------------------------------------------------
-	 frame_file_deltaT += INT_4U( data_dt );
-#endif /* 0 */
-	 if ( ( --frames_to_write ) == 0 )
-	 {
-	    //-----------------------------------------------------------
-	    // Close the output file.
-	    //-----------------------------------------------------------
-	    m_stream->Close( false );
-	    //-----------------------------------------------------------
-	    // Reset
-	    //-----------------------------------------------------------
-#if 0
-	    frames_per_file = m_options.FramesPerFile( );
-	    frame_file_start += frame_file_deltaT;
-	    frame_file_deltaT = 0;
-#endif /* 0 */
-	 }
 	 //--------------------------------------------------------------
 	 // Advance to the next frame and set the length of the
 	 //   dt appropriately
 	 //--------------------------------------------------------------
-	 frame_start += data_dt;
-	 if ( frame_start == user_start )
+	 data_start += data_dt;
+	 if ( ( data_start >= user_start )
+	      && ( data_start < user_stop ) )
 	 {
 	    // Set data_dt to the size requested by the user
 	    data_dt = m_options.SecondsPerFrame( );
-#if 0
-	    frame_file_start = frame_start.GetSeconds( );
-	    frame_file_deltaT = 0;
-	    is_last_frame_of_file = m_options.FramesPerFile( );
-#endif /* 0 */
+	    QUEUE_LOG_MESSAGE( "Reset"
+			       << " data_dt: " << data_dt
+			       << std::endl << "\t[ Line: " << __LINE__ << " File: " << __FILE__ << "]"
+			       ,
+			       MT_DEBUG, 30,
+			       caller,
+			       "CreateRDS" );
 	    continue;
 	 }
-	 else if ( frame_start == user_stop )
+	 else if ( data_start == user_stop )
 	 {
 	    // Set data_dt to the remainder of data
-	    data_dt = data_stop - frame_start;
+	    data_dt = data_stop - data_start;
+	    QUEUE_LOG_MESSAGE( "Reset"
+			       << " data_dt: " << data_dt
+			       << std::endl << "\t[ Line: " << __LINE__ << " File: " << __FILE__ << "]"
+			       ,
+			       MT_DEBUG, 30,
+			       caller,
+			       "CreateRDS" );
 	 }
-	 else if ( (frame_start < user_stop ) &&
-		   ( ( frame_start + data_dt ) > user_stop ) )
+	 else if ( (data_start < user_stop ) &&
+		   ( ( data_start + data_dt ) > user_stop ) )
 	 {
 	    // Set data_dt to the remainder of user data
-	    data_dt = user_stop - frame_start;
+	    data_dt = user_stop - data_start;
+	    QUEUE_LOG_MESSAGE( "Reset"
+			       << " data_dt: " << data_dt
+			       << std::endl << "\t[ Line: " << __LINE__ << " File: " << __FILE__ << "]"
+			       ,
+			       MT_DEBUG, 30,
+			       caller,
+			       "CreateRDS" );
 	 }
       }
 
@@ -1111,23 +1123,7 @@ ProcessRequest( stream_type Output )
       //----------------------------------------------------------------
       // close out any pending requests
       //----------------------------------------------------------------
-#if 0
-      if ( ( GPSTime( frame_file_start, 0 ) + frame_file_deltaT ) > user_stop )
-      {
-	 if ( GPSTime( frame_file_start, 0 ) > user_stop )
-	 {
-	    frame_file_deltaT = 0;
-	 } else {
-	    frame_file_deltaT =
-	       INT_4U( ceil( user_stop - GPSTime( frame_file_start, 0 ) ) );
-	 }
-      }
-      closeFrameFile( generateOutputName( frame_file_start,
-					  frame_file_deltaT ),
-		      true );
-#else
       m_stream->Close( true );
-#endif /* 0 */
    }
    catch( const SwigException& E )
    {
@@ -1170,20 +1166,14 @@ getChannelName( INT_4U offset ) const
    return m_p->GetChannelCache( ).operator[]( offset ).GetName( );
 }
 
-#if 0
-void RDSFrame::
-closeFrameFile( const std::string& Filename, bool Final )
-{
-   m_stream->Close( Filename, Final );
-}
-#endif /* 0 */
-
 void RDSFrame::
 writeFrameToStream( )
 {
    static const char* caller = "RDSFrame::writeFrameToStream";
 
    QUEUE_LOG_MESSAGE( "Writing frame"
+		      << " Start Time: " << mResultFrame->GetGTime( )
+		      << " Dt: " << mResultFrame->GetDt( )
 		      << " with: " << ( ( mResultFrame->GetRawData( ) )
 					? mResultFrame->GetRawData( )->RefFirstAdc( ).size( )
 					: 0 )
@@ -1331,24 +1321,6 @@ const std::string& RDSFrame::getHistoryName()
    return mHistoryName;
 }
 
-#if 0
-std::string RDSFrame::
-generateOutputName( INT_4U FileStart, REAL_8 FileDeltaT ) const
-{
-   //--------------------------------------------------------------------
-   // Generate an output file
-   //--------------------------------------------------------------------
-   std::ostringstream	oss;
-   oss << m_options.OutputDirectory( ) << "/"
-       << m_ifo_list << "-" << m_options.OutputType( )
-       << m_options.RDSLevel( ) << "-"
-       << FileStart
-       << "-"
-       << FileDeltaT
-       << ".gwf";
-   return oss.str( );
-}
-#endif /* 0 */
 
 void RDSFrame::
 init( const frame_file_container_type& FrameFiles, 
