@@ -200,13 +200,17 @@ ResampleRawFrame( const char* frame_files,
      mCurrentDt( 0.0f ),
      m_should_write( false )
 {
+   static const char* caller = "ResampleRawFrame::ResampleRawFrame";
+
+   m_remaining_to_write_to_file = m_options.FramesPerFile( );
    if( Resampling == 0 || strlen( Resampling ) == 0 )
    {
       throw SWIGEXCEPTION( "Resample factor must be specified." );      
    }
 
    // At least three files must be specified
-   if( GetNumberOfFrameFiles( ) < 3 )
+   if( ( GetNumberOfFrameFiles( ) < 3 )
+       && ( UserOptions.Padding( ) == 0 ) )
    {
       throw SWIGEXCEPTION( "At least three frame files must be specified." );
    }
@@ -219,6 +223,14 @@ ResampleRawFrame( const char* frame_files,
    {
       throw SWIGEXCEPTION( "Inconsistent number of channels and resample factors." );
    }
+   QUEUE_LOG_MESSAGE( "ResampleRawFrame:"
+		      << " frame_files: " << frame_files
+		      << " channels: " << channels
+		      << " Resampling: " << Resampling
+		      ,
+		      MT_DEBUG, 30,
+		      caller,
+		      "RDSResample" );
 }   
    
 ResampleRawFrame::
@@ -230,10 +242,14 @@ ResampleRawFrame( const frame_file_container_type& frame_files,
      mCurrentDt( 0.0f ),
      m_should_write( false )
 {
+   static const char* caller = "ResampleRawFrame::ResampleRawFrame";
+
+   m_remaining_to_write_to_file = m_options.FramesPerFile( );
    //--------------------------------------------------------------------
    // At least three files must be specified
    //--------------------------------------------------------------------
-   if( GetNumberOfFrameFiles( ) < 3 )
+   if( ( GetNumberOfFrameFiles( ) < 3 )
+       && ( UserOptions.Padding( ) == 0 ) )
    {
       throw SWIGEXCEPTION( "At least three frame files must be specified." );
    }
@@ -282,6 +298,23 @@ ResampleRawFrame( const frame_file_container_type& frame_files,
    {
       throw SWIGEXCEPTION( "Inconsistent number of channels and resample factors." );
    }
+#if WIP
+   QUEUE_LOG_MESSAGE( "ResampleRawFrame:"
+		      << " frame_files: " << frame_files
+		      << " channels: " << channels
+		      << " Resampling: " << Resampling
+		      ,
+		      MT_DEBUG, 30,
+		      caller,
+		      "RDSResample" );
+#else /* WIP */
+   QUEUE_LOG_MESSAGE( "ResampleRawFrame:"
+		      << "..."
+		      ,
+		      MT_DEBUG, 30,
+		      caller,
+		      "RDSResample" );
+#endif /* WIP */
 }
 
 //-----------------------------------------------------------------------------
@@ -685,6 +718,15 @@ openFrameFile( const std::string& Filename )
 }
 #endif /* 0 */
 
+void ResampleRawFrame::
+rangeOptimizer( const time_type& UserStart,
+		const time_type& UserStop,
+		time_type& DataStart,
+		time_type& DataStop ) const
+{
+   return;
+}
+			
 void ResampleRawFrame::
 writeFrameToStream( )
 {
@@ -708,44 +750,23 @@ writeFrameToStream( )
 		      MT_DEBUG, 30,
 		      caller,
 		      "RDSResample" );
-   QUEUE_LOG_MESSAGE( "mResultFrame: " << (void*)(mCurrentFrame.get( ) )
-		      << " mResultFrame->GetGTime(): "
-		      << ( ( mResultFrame.get( ) )
-			   ? mResultFrame->GetGTime( )
-			   : GPSTime( 0, 0 ) )
-		      << " mResultFrame->GetDt(): "
-		      << ( ( mResultFrame.get() )
-			   ? mResultFrame->GetDt( )
-			   : 0.0 )
-		      << " Should Start: " << GPSTime( m_options.OutputTimeStart( ), 0 ),
-		      MT_DEBUG, 30,
-		      caller,
-		      "RDSResample" );
-   QUEUE_LOG_MESSAGE( "m_should_write: " << m_should_write
-		      << " mCurrentFrame: " << (void*)( mCurrentFrame.get( ) )
-		      << " GetGTime: " << ( ( mCurrentFrame )
-					    ? mCurrentFrame->GetGTime( )
-					    : GPSTime( 0, 0 ) )
-		      << " output StartTime: "
-		      << GPSTime( m_options.OutputTimeStart( ), 0 ),
-		      MT_DEBUG, 20,
-		      caller,
-		      "RDSResample" );
    if ( ( m_should_write == false ) &&
 	( mCurrentFrame.get( ) ) &&
 	( mCurrentFrame->GetGTime( ) >=
 	  GPSTime( m_options.OutputTimeStart( ), 0 ) ) )
    {
-      QUEUE_LOG_MESSAGE( "__LINE__: " << __LINE__,
+      QUEUE_LOG_MESSAGE( "Flagging as should write" << __LINE__,
 			 MT_DEBUG, 40,
 			 caller,
 			 "RDSResample" );
 
       m_should_write = true;
-      m_is_last_frame_of_file = m_options.FramesPerFile( );
+      m_remaining_to_write_to_file = m_options.FramesPerFile( );
    }
-   QUEUE_LOG_MESSAGE( "m_should_write: " << m_should_write
-		      << " mCurrentFrame: " << (void*)( mCurrentFrame.get( ) ),
+   QUEUE_LOG_MESSAGE( "mCurrentFrame: " << (void*)( mCurrentFrame.get( ) )
+		      << " m_should_write: " << m_should_write
+		      << " m_remaining_to_write_to_file: " << m_remaining_to_write_to_file
+		      ,
 		      MT_DEBUG, 30,
 		      caller,
 		      "RDSResample" );
@@ -785,22 +806,6 @@ writeFrameToStream( )
 		       ( ( m_options.CreateChecksumPerFrame( ) )
 			 ? CheckSum::CRC
 			 : CheckSum::NONE ) );
-      //-----------------------------------------------------------------
-      // Check to see if the file has been stuffed with all its frames.
-      //-----------------------------------------------------------------
-      QUEUE_LOG_MESSAGE( "__LINE__: " << __LINE__,
-			 MT_DEBUG, 40,
-			 caller,
-			 "RDSResample" );
-
-      if ( ( --m_is_last_frame_of_file ) == 0 )
-      {
-	 QUEUE_LOG_MESSAGE( "__LINE__: " << __LINE__,
-			    MT_DEBUG, 40,
-			    caller,
-			    "RDSResample" );
-	 m_stream->Close( false );
-      }
    }
    //--------------------------------------------------------------------
    // Setup for the next frame
