@@ -13,6 +13,8 @@
 #include "createRDS.hh"
 #include "Frame.hh"
 
+//  LDAS_TEST_FRAMES_DIR -
+
 LDASTools::Testing::UnitTest	Test;
 
 typedef std::list< std::string > base_filename_container_type;
@@ -41,12 +43,20 @@ public:
   typedef INT_4U start_time_type;
   typedef INT_4U dt_type;
 
+  static const INT_4U SET_O1_LLO_START = 1133126912;
+  static const INT_4U SET_O1_LLO_DT = 64;
+  static const INT_4U SET_O1_LLO_FRAMES = 10;
+
   typedef enum {
+    SET_O1_LHO,
+    SET_O1_LLO,
     SET_S6_LHO,
     SET_S6_LLO,
     SET_S5
   } set_type;
 
+  static const char* DQ[6];
+
   TestSet( );
 
   void AddSet( set_type Set );
@@ -140,6 +150,7 @@ Initialize( )
   FrameCPP::Initialize( );
   SEARCH_DIRS.AddPathVar( "LDAS_TEST_FRAMES_DIR", "" );
   SEARCH_DIRS.AddPathVar( "HOME", "tmp" );
+  SEARCH_DIRS.AddPathVar( "HOME", "mnt/hdfs" );
 }
 
 void
@@ -151,7 +162,7 @@ TestCreateRDS( )
 
   TestSet	file_set;
 
-  file_set( "H-SIDv1_H1H2_250mHz-821935753-26.gwf", 821935753, 26 );
+  file_set.AddSet( TestSet::SET_O1_LLO );
   file_set.Find( SEARCH_DIRS, frame_files );
 
   if ( frame_files.size( ) <= 0 )
@@ -164,11 +175,32 @@ TestCreateRDS( )
   Test.Message( 10 ) << func_name << ": Start"
 		     << std::endl
     ;
+  Test.Message( 20 ) << func_name << ": files[0]: " << frame_files.front( )
+		     << std::endl
+    ;
   try
   {
-    FrameAPI::Catalog::gps_seconds_type		start( 821935753);
-    FrameAPI::Catalog::gps_seconds_type		stop( start + 16 );
+    static char					cwd[ 1024 ];
+
+    FrameAPI::Catalog::gps_seconds_type		start( TestSet::SET_O1_LLO_START + 2 * TestSet::SET_O1_LLO_DT );
+    FrameAPI::Catalog::gps_seconds_type		stop( start + ( TestSet::SET_O1_LLO_DT ) );
+    const char*					dq_channel( TestSet::DQ[ TestSet::SET_O1_LLO] );
     FrameAPI::Catalog::channel_container_type	channels;
+    FrameAPI::RDS::FileOptions			options;
+
+    //-------------------------------------------------------------------
+    // Setup options
+    //-------------------------------------------------------------------
+    if ( getcwd( cwd, sizeof( cwd ) ) == NULL )
+    {
+      throw std::runtime_error( "Unable to get current working directory" );
+    }
+
+    options.OutputTimeStart( start );
+    options.OutputTimeEnd( stop );
+    options.DirectoryOutputFrames( cwd );
+    options.DirectoryOutputMD5Sum( cwd );
+    options.OutputType( func_name );
 
     //-------------------------------------------------------------------
     // Attempt to read the file
@@ -176,7 +208,7 @@ TestCreateRDS( )
     FrameAPI::Frame			frame;
     FrameAPI::Frame::channel_type	as_q;
 
-    channels.names.push_back( "H1:AdjacentPSD" );
+    channels.names.push_back( dq_channel );
     Test.Message( 10 ) << func_name << ": About to create frame"
 		       << std::endl
       ;
@@ -184,7 +216,7 @@ TestCreateRDS( )
     Test.Message( 10 ) << func_name << ": Created frame"
 		       << std::endl
       ;
-    as_q = frame.GetChannel( "H1:AdjacentPSD" );
+    as_q = frame.GetChannel( dq_channel );
     Test.Message( 10 ) << func_name << ": as_q.name: " << as_q->GetName( ) << std::endl;
     Test.Message( 10 ) << func_name << ": as_q.unitY: " << as_q->GetUnitY( ) << std::endl;
     Test.Message( 10 ) << func_name << ": as_q.data[0].name: "
@@ -222,7 +254,7 @@ TestCreateRDSResample( )
 
   TestSet	file_set;
 
-  file_set.AddSet( TestSet::SET_S6_LLO );
+  file_set.AddSet( TestSet::SET_O1_LLO );
   file_set.Find( SEARCH_DIRS, frame_files );
 
   if ( frame_files.size( ) <= 0 )
@@ -230,7 +262,7 @@ TestCreateRDSResample( )
     //-------------------------------------------------------------------
     // No files to process
     //-------------------------------------------------------------------
-    Test.Message( 30 ) << func_name << "Skipped because no files to process"
+    Test.Message( 30 ) << func_name << ": Skipped because no files to process"
 		       << std::endl
       ;
     return;
@@ -242,8 +274,9 @@ TestCreateRDSResample( )
   {
     static char					cwd[ 1024 ];
 
-    FrameAPI::RDS::Options::start_type		start( 971603040 );
-    FrameAPI::RDS::Options::end_type		stop( start + 96 );
+    FrameAPI::RDS::Options::start_type		start( TestSet::SET_O1_LLO_START + 2 * TestSet::SET_O1_LLO_DT );
+    FrameAPI::RDS::Options::end_type		stop( start + ( 3 * TestSet::SET_O1_LLO_DT ) );
+    const char*					dq_channel( TestSet::DQ[ TestSet::SET_O1_LLO] );
     FrameAPI::Catalog::channel_container_type	channels;
     FrameAPI::RDS::FileOptions		      	options;
 
@@ -260,11 +293,12 @@ TestCreateRDSResample( )
     options.OutputTimeEnd( stop );
     options.DirectoryOutputFrames( cwd );
     options.DirectoryOutputMD5Sum( cwd );
+    options.OutputType( "test_createRDS_cpp" );
 
     //-------------------------------------------------------------------
     // Attempt to create a set of RDS frames from the input set
     //-------------------------------------------------------------------
-    channels.names.push_back( "L1:LSC-AS_Q" );
+    channels.names.push_back( dq_channel );
     FrameAPI::createRDSSet( frame_files, channels, options );
   }
   catch( const SwigException& E )
@@ -340,6 +374,12 @@ TestExceptionMissingChannel( )
     Test.Message( 10 ) << func_name << ": as_q.data[0].name: "
 		       << as_q->RefData( )[ 0 ]->GetName( ) << std::endl;
   }
+  catch( const FrameAPI::Frame::NoChannelFound& E )
+  {
+    Test.Check( true ) << func_name << ": Caught expected exception: " << E.what( )
+		       << std::endl
+      ;
+  }
   catch( const FrameAPI::RDS::MissingChannel& E )
   {
     Test.Check( true ) << func_name << ": Caught expected exception: " << E.what( )
@@ -441,6 +481,15 @@ TestOpenData( )
   }
 }
 
+const char* TestSet::DQ[6] = {
+  /* O1_LHO */ "H1:CAL-DELTAL_EXTERNAL_DQ",
+  /* O1_LLO */ "L1:CAL-DELTAL_EXTERNAL_DQ",
+  /* S6_LHO */ "H1::LSC-AS_Q",
+  /* S6_LLO */ "L1:LSC-AS_Q",
+  /* S5 */ "H1:LSC-AS_Q",
+  /* <Out of Range> */ "Z1:BadChannel"
+};
+
 TestSet::
 TestSet( )
 {
@@ -453,6 +502,18 @@ AddSet( set_type Set )
 
   switch( Set )
   {
+  case SET_O1_LHO:
+    mkset( 1129247488, 64, 10,
+	   "frames/O1/raw/H1/H-H1_R-11292/",
+	   "H-H1_R-" );
+    break;
+  case SET_O1_LLO:
+    mkset( TestSet::SET_O1_LLO_START,
+	   TestSet::SET_O1_LLO_DT,
+	   TestSet::SET_O1_LLO_FRAMES,
+	   "frames/O1/raw/L1/L-L1_R-11331/",
+	   "L-L1_R-" );
+    break;
   case SET_S6_LHO:
     mkset( 971621600, 32, 10,
 	   "S6/L0/LHO/H-R-9716/",
